# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.identity_response import IdentityResponse


class TestIdentityResponse(unittest.TestCase):
    """IdentityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IdentityResponse:
        """Test IdentityResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `IdentityResponse`
        """
        model = IdentityResponse()
        if include_optional:
            return IdentityResponse(
                accounts = [
                    moneykit.models.account_identity.AccountIdentity(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, 
                        owners = [
                            moneykit.models.owner.Owner(
                                names = [
                                    ''
                                    ], 
                                addresses = [
                                    moneykit.models.address.Address(
                                        city = '', 
                                        country = '', 
                                        postal_code = '', 
                                        region = '', 
                                        street = '', 
                                        primary = True, )
                                    ], 
                                phone_numbers = [
                                    moneykit.models.phone_number.PhoneNumber(
                                        number = '', 
                                        primary = True, 
                                        type = null, )
                                    ], 
                                emails = [
                                    moneykit.models.email.Email(
                                        address = '', 
                                        primary = True, )
                                    ], )
                            ], )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], )
            )
        else:
            return IdentityResponse(
                accounts = [
                    moneykit.models.account_identity.AccountIdentity(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, 
                        owners = [
                            moneykit.models.owner.Owner(
                                names = [
                                    ''
                                    ], 
                                addresses = [
                                    moneykit.models.address.Address(
                                        city = '', 
                                        country = '', 
                                        postal_code = '', 
                                        region = '', 
                                        street = '', 
                                        primary = True, )
                                    ], 
                                phone_numbers = [
                                    moneykit.models.phone_number.PhoneNumber(
                                        number = '', 
                                        primary = True, 
                                        type = null, )
                                    ], 
                                emails = [
                                    moneykit.models.email.Email(
                                        address = '', 
                                        primary = True, )
                                    ], )
                            ], )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], ),
        )
        """

    def testIdentityResponse(self):
        """Test IdentityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.institution import Institution


class TestInstitution(unittest.TestCase):
    """Institution unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Institution:
        """Test Institution
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Institution`
        """
        model = Institution()
        if include_optional:
            return Institution(
                institution_id = '',
                institution_id_aliases = [
                    ''
                    ],
                name = '',
                country = 'US',
                domain = '',
                color = '',
                color_dark = '',
                is_featured = True
            )
        else:
            return Institution(
                institution_id = '',
                institution_id_aliases = [
                    ''
                    ],
                name = '',
                country = 'US',
                is_featured = True,
        )
        """

    def testInstitution(self):
        """Test Institution"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List
from pydantic import BaseModel
from moneykit.models.ach_number import AchNumber
from moneykit.models.bacs_number import BacsNumber
from moneykit.models.eft_number import EftNumber
from moneykit.models.international_number import InternationalNumber

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class AccountNumbersLegacy20230218(BaseModel):
    """
    AccountNumbersLegacy20230218
    """  # noqa: E501

    ach: List[AchNumber]
    eft: List[EftNumber]
    bacs: List[BacsNumber]
    international: List[InternationalNumber]
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["ach", "eft", "bacs", "international"]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AccountNumbersLegacy20230218 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in ach (list)
        _items = []
        if self.ach:
            for _item in self.ach:
                if _item:
                    _items.append(_item.to_dict())
            _dict["ach"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in eft (list)
        _items = []
        if self.eft:
            for _item in self.eft:
                if _item:
                    _items.append(_item.to_dict())
            _dict["eft"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in bacs (list)
        _items = []
        if self.bacs:
            for _item in self.bacs:
                if _item:
                    _items.append(_item.to_dict())
            _dict["bacs"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in international (list)
        _items = []
        if self.international:
            for _item in self.international:
                if _item:
                    _items.append(_item.to_dict())
            _dict["international"] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AccountNumbersLegacy20230218 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "ach": [AchNumber.from_dict(_item) for _item in obj.get("ach")]
                if obj.get("ach") is not None
                else None,
                "eft": [EftNumber.from_dict(_item) for _item in obj.get("eft")]
                if obj.get("eft") is not None
                else None,
                "bacs": [BacsNumber.from_dict(_item) for _item in obj.get("bacs")]
                if obj.get("bacs") is not None
                else None,
                "international": [
                    InternationalNumber.from_dict(_item)
                    for _item in obj.get("international")
                ]
                if obj.get("international") is not None
                else None,
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from moneykit.models.link_products import LinkProducts
from moneykit.models.product import Product
from moneykit.models.provider import Provider
from moneykit.models.public_link_error import PublicLinkError
from moneykit.models.public_link_state import PublicLinkState

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class LinkCommon(BaseModel):
    """
    LinkCommon
    """  # noqa: E501

    link_id: StrictStr = Field(description="The unique ID for this link.")
    institution_id: StrictStr = Field(
        description="The unique ID for the institution this link is connected to."
    )
    institution_name: StrictStr = Field(
        description="The institution name this link is connected to."
    )
    institution_avatar: StrictStr = Field(
        description="An avatar image for the link's institution."
    )
    state: PublicLinkState
    error_code: Optional[PublicLinkError] = None
    last_synced_at: Optional[datetime] = Field(
        default=None,
        description="(Deprecated) An ISO-8601 timestamp indicating the last time that the link was updated.",
    )
    provider: Provider
    link_tags: Optional[List[StrictStr]] = None
    tags: Optional[List[StrictStr]] = None
    webhook: Optional[StrictStr] = Field(
        default=None, description="The webhook url assigned to this link."
    )
    products: LinkProducts
    available_products: List[Product]
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "link_id",
        "institution_id",
        "institution_name",
        "institution_avatar",
        "state",
        "error_code",
        "last_synced_at",
        "provider",
        "link_tags",
        "tags",
        "webhook",
        "products",
        "available_products",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LinkCommon from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of products
        if self.products:
            _dict["products"] = self.products.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of LinkCommon from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "link_id": obj.get("link_id"),
                "institution_id": obj.get("institution_id"),
                "institution_name": obj.get("institution_name"),
                "institution_avatar": obj.get("institution_avatar"),
                "state": obj.get("state"),
                "error_code": obj.get("error_code"),
                "last_synced_at": obj.get("last_synced_at"),
                "provider": obj.get("provider"),
                "link_tags": obj.get("link_tags"),
                "tags": obj.get("tags"),
                "webhook": obj.get("webhook"),
                "products": LinkProducts.from_dict(obj.get("products"))
                if obj.get("products") is not None
                else None,
                "available_products": obj.get("available_products"),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.identity_api import IdentityApi


class TestIdentityApi(unittest.TestCase):
    """IdentityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityApi()

    def tearDown(self) -> None:
        pass

    def test_get_identities(self) -> None:
        """Test case for get_identities

        /links/{id}/identity
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.accounts_api import AccountsApi


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountsApi()

    def tearDown(self) -> None:
        pass

    def test_get_account(self) -> None:
        """Test case for get_account

        /links/{id}/accounts/{account_id}
        """
        pass

    def test_get_account_numbers(self) -> None:
        """Test case for get_account_numbers

        /links/{id}/accounts/numbers
        """
        pass

    def test_get_accounts(self) -> None:
        """Test case for get_accounts

        /links/{id}/accounts
        """
        pass

    def test_get_user_accounts(self) -> None:
        """Test case for get_user_accounts

        /users/{id}/accounts
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.investment_transaction_response import (
    InvestmentTransactionResponse,
)


class TestInvestmentTransactionResponse(unittest.TestCase):
    """InvestmentTransactionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvestmentTransactionResponse:
        """Test InvestmentTransactionResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `InvestmentTransactionResponse`
        """
        model = InvestmentTransactionResponse()
        if include_optional:
            return InvestmentTransactionResponse(
                investment_transaction_id = '',
                account_id = '',
                amount = '',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                description = '',
                type = '',
                fees = '',
                forex_rate = '',
                price = '',
                quantity = '',
                security_id = ''
            )
        else:
            return InvestmentTransactionResponse(
                investment_transaction_id = '',
                account_id = '',
                amount = '',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                description = '',
                type = '',
        )
        """

    def testInvestmentTransactionResponse(self):
        """Test InvestmentTransactionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.basic_account_details import BasicAccountDetails


class TestBasicAccountDetails(unittest.TestCase):
    """BasicAccountDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BasicAccountDetails:
        """Test BasicAccountDetails
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BasicAccountDetails`
        """
        model = BasicAccountDetails()
        if include_optional:
            return BasicAccountDetails(
                name = '',
                last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                institution_id = '',
                link_id = ''
            )
        else:
            return BasicAccountDetails(
                name = '',
                institution_id = '',
                link_id = '',
        )
        """

    def testBasicAccountDetails(self):
        """Test BasicAccountDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel
from pydantic import Field
from typing_extensions import Annotated
from moneykit.models.customer_user_email import CustomerUserEmail
from moneykit.models.customer_user_phone import CustomerUserPhone

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class CustomerUser(BaseModel):
    """
    CustomerUser
    """  # noqa: E501

    id: Annotated[str, Field(min_length=4, strict=True, max_length=150)] = Field(
        description="Your own unique ID for this user.  Typically this will be a UUID or primary key         from your application."
    )
    email: Optional[CustomerUserEmail] = None
    phone: Optional[CustomerUserPhone] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "email", "phone"]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CustomerUser from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of email
        if self.email:
            _dict["email"] = self.email.to_dict()
        # override the default output from pydantic by calling `to_dict()` of phone
        if self.phone:
            _dict["phone"] = self.phone.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of CustomerUser from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "email": CustomerUserEmail.from_dict(obj.get("email"))
                if obj.get("email") is not None
                else None,
                "phone": CustomerUserPhone.from_dict(obj.get("phone"))
                if obj.get("phone") is not None
                else None,
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class CustomSandboxAccount(BaseModel):
    """
    CustomSandboxAccount
    """  # noqa: E501

    account_type: StrictStr = Field(
        description="Account type applied to the sandbox account. See <a href=/pages/account_types>Account Types</a> for a full listing."
    )
    name: StrictStr = Field(description="Account name used for the sandbox account.")
    account_number: StrictStr = Field(
        description="Account number used for the sandbox account."
    )
    routing_number: Optional[StrictStr] = Field(
        default=None,
        description="Routing number used for the sandbox account (if applicable). Must follow the standard ABA routing transit number format with a valid check digit, but does not need to be a real bank's routing number.",
    )
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "account_type",
        "name",
        "account_number",
        "routing_number",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CustomSandboxAccount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of CustomSandboxAccount from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "account_type": obj.get("account_type"),
                "name": obj.get("name"),
                "account_number": obj.get("account_number"),
                "routing_number": obj.get("routing_number"),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj
